==> checker-3.4.0.jar: annotated-jdk/src/java.base/share/classes/java/util/zip/GZIPOutputStream.java <==
/*
 * Copyright (c) 1996, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.zip;

import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.Positive;
import org.checkerframework.checker.signedness.qual.PolySigned;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.io.OutputStream;
import java.io.IOException;
import org.checkerframework.framework.qual.CFComment;

@AnnotatedFor({ "index", "signedness" })
public class GZIPOutputStream extends DeflaterOutputStream {

    protected CRC32 crc;

    public GZIPOutputStream(OutputStream out, @Positive int size) throws IOException {
    }

    public GZIPOutputStream(OutputStream out, @Positive int size, boolean syncFlush) throws IOException {
    }

    public GZIPOutputStream(OutputStream out) throws IOException {
    }

    public GZIPOutputStream(OutputStream out, boolean syncFlush) throws IOException {
    }

    public synchronized void write(@PolySigned byte[] buf, @IndexOrHigh({ "#1" }) int off, @IndexOrHigh({ "#1" }) int len) throws IOException;

    public void finish() throws IOException;
}

==> checker-3.18.0.jar: annotated-jdk/src/java.base/share/classes/java/util/zip/GZIPOutputStream.java <==
/*
 * Copyright (c) 1996, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.zip;

import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.Positive;
import org.checkerframework.checker.mustcall.qual.MustCallAlias;
import org.checkerframework.checker.signedness.qual.PolySigned;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.io.OutputStream;
import java.io.IOException;
import org.checkerframework.framework.qual.CFComment;

@AnnotatedFor({ "index", "mustcall", "signedness" })
public class GZIPOutputStream extends DeflaterOutputStream {

    protected CRC32 crc;

    @MustCallAlias
    public GZIPOutputStream(@MustCallAlias OutputStream out, @Positive int size) throws IOException {
    }

    @MustCallAlias
    public GZIPOutputStream(@MustCallAlias OutputStream out, @Positive int size, boolean syncFlush) throws IOException {
    }

    @MustCallAlias
    public GZIPOutputStream(@MustCallAlias OutputStream out) throws IOException {
    }

    @MustCallAlias
    public GZIPOutputStream(@MustCallAlias OutputStream out, boolean syncFlush) throws IOException {
    }

    public synchronized void write(@PolySigned byte[] buf, @IndexOrHigh({ "#1" }) int off, @IndexOrHigh({ "#1" }) int len) throws IOException;

    public void finish() throws IOException;
}
